# pdf2doi4frappe_library 

```pdf2doi4frappe_library``` is a Python library tool to automatically extract the DOI or ISBN from a .pdf file of a publication,
and to retrieve bibliographic information. It is a fork of MicheleCotrufo's pdf2doi with most of its functionality, though reduced in order
to accomodate my specific needs for a library-type-application in the frappe framework.

```bash
pip install pdf2doi4frappe_library
```


## License
[MIT](https://choosealicense.com/licenses/mit/)

